@@ -7,6 +7,7 @@ from ocrd.cli.bashlib import bashlib_cli
 from ocrd.cli.validate import validate_cli
 from ocrd.decorators import ocrd_loglevel
 from .zip import zip_cli
+from .log import log_cli
 
 @click.group()
 @click.version_option()
@@ -22,3 +23,4 @@ cli.add_command(process_cli)
 cli.add_command(bashlib_cli)
 cli.add_command(zip_cli)
 cli.add_command(validate_cli)
+cli.add_command(log_cli)
